@@ -6,12 +6,15 @@ from .drop_table import DropTable as DropTable
 from .insert import InsertQuery as InsertQuery
 from .joins import JoinSelector as JoinSelector
 from .joins import JoinType as JoinType
-from .limit import LimitQuery as LimitQuery
-from .offset import OffsetQuery as OffsetQuery
-from .order import OrderQuery as OrderQuery
+from .limit import Limit as Limit
+from .offset import Offset as Offset
+from .order import Order as Order
 from .update import UpdateQuery as UpdateQuery
 from .upsert import UpsertQuery as UpsertQuery
-from .where_condition import WhereCondition as WhereCondition
+from .where import Where as Where
+from .having import Having as Having
 from .count import Count as Count
 from .group_by import GroupBy as GroupBy
 from .alias import Alias as Alias
+from .ST_AsText import ST_AsText as ST_AsText
+from .select import Select as Select
