@@ -1,12 +1,11 @@
 import contextlib
-from typing import Generator, Type
+from typing import Generator, Type, Unpack
 from ormlambda.repository import IRepositoryBase
 import abc
 
 
 class BaseRepository[TPool](IRepositoryBase):
-    def __init__(self, pool: Type[TPool], **kwargs: str) -> None:
-        self._data_config: dict[str, str] = kwargs
+    def __init__[TArgs](self, pool: Type[TPool], **kwargs: Unpack[TArgs]) -> None:
         self._pool: TPool = pool(**kwargs)
 
     @contextlib.contextmanager
