@@ -29,6 +29,8 @@ from ..types import (
     WhereTypes,
 )
 
+type SelectCols[T, TProp] = Callable[[T], ColumnType[TProp]] | ColumnType[TProp]
+
 
 class IStatements[T: Table](ABC):
     @abstractmethod
@@ -132,7 +134,7 @@ class IStatements[T: Table](ABC):
     @abstractmethod
     def count(
         self,
-        selection: Callable[[T], tuple] = lambda x: "*",
+        selection: Callable[[T], tuple] = ...,
         alias_clause="count",
         execute: bool = False,
     ) -> Optional[IStatements[T]]: ...
@@ -160,6 +162,16 @@ class IStatements[T: Table](ABC):
     @abstractmethod
     def where[LProp, RTable, RProp](self, conditions: WhereTypes[T, LProp, RTable, RProp] = None) -> IStatements[T]: ...
 
+    # endregion
+
+    # region having
+
+    @overload
+    def having[LProp, RTable, RProp](self, conditions: Callable[[T], WhereTypes[T, LProp, RTable, RProp]]) -> IStatements[T]: ...
+
+    @abstractmethod
+    def having[LProp, RTable, RProp](self, conditions: WhereTypes[T, LProp, RTable, RProp] = None) -> IStatements[T]: ...
+
     # endregion
     # region order
     @overload
@@ -172,14 +184,14 @@ class IStatements[T: Table](ABC):
     # endregion
     # region concat
     @overload
-    def concat[P](self, selector: Callable[[T], tuple[P]]) -> IAggregate: ...
+    def concat(self, selector: Callable[[T], str], alias: str = "CONCAT") -> IAggregate: ...
 
     # endregion
     # region max
     @overload
     def max[TProp](
         self,
-        column: Callable[[T], TProp],
+        column: SelectCols[T, TProp],
         alias: Optional[str] = ...,
         execute: bool = ...,
     ) -> TProp: ...
@@ -188,7 +200,7 @@ class IStatements[T: Table](ABC):
     @overload
     def min[TProp](
         self,
-        column: Callable[[T], TProp],
+        column: SelectCols[T, TProp],
         alias: Optional[str] = ...,
         execute: bool = ...,
     ) -> TProp: ...
@@ -197,7 +209,7 @@ class IStatements[T: Table](ABC):
     @overload
     def sum[TProp](
         self,
-        column: Callable[[T], TProp],
+        column: SelectCols[T, TProp],
         alias: Optional[str] = ...,
         execute: bool = ...,
     ) -> TProp: ...
@@ -208,6 +220,8 @@ class IStatements[T: Table](ABC):
     # endregion
     # region select
     type SelectorType[TOri, *T] = Callable[[TOri], tuple[*T]] | tuple[*T]
+    type SelectorFlavourType[T, TResponse] = Optional[Callable[[T], TResponse]] | TResponse
+    type SelectorOneType[T, TResponse] = Callable[[T, TResponse]] | TResponse
 
     @overload
     def select[T1, T2, T3, T4, T5, T6, T7, T8, T9, T10](self, selector: SelectorType[T, T1, T2, T3, T4, T5, T6, T7, T8, T9, T10], *, by: Optional[Enum] = ...) -> Select10[T1, T2, T3, T4, T5, T6, T7, T8, T9, T10]: ...
@@ -234,8 +248,6 @@ class IStatements[T: Table](ABC):
     @overload
     def select(self) -> Tuple[T]: ...
 
-    type SelectorFlavourType[T, TResponse] = Optional[Callable[[T], TResponse]]
-
     # @overload
     # def select[TFlavour](self, selector: Optional[Callable[[T], tuple]] = ..., *, cast_to_tuple: bool = ..., flavour: Type[TFlavour], by: Optional[Enum] = ..., **kwargs) -> TFlavour: ...
     @overload
@@ -243,7 +255,7 @@ class IStatements[T: Table](ABC):
     @overload
     def select[*TRes](self, selector: SelectorFlavourType[T, tuple[*TRes]] = ..., *, flavour: Type[tuple], by: Optional[Enum] = ..., **kwargs) -> tuple[tuple[*TRes]]: ...
     @overload
-    def select[TFlavour](self, selector: SelectorFlavourType[T, tuple] = ..., *, flavour: Type[TFlavour], by: Optional[Enum] = ..., **kwargs) -> tuple[TFlavour]: ...
+    def select[TFlavour](self, selector: SelectorFlavourType[T, tuple] = ..., *, flavour: Type[TFlavour], by: Optional[Enum] = ..., **kwargs) -> tuple[TFlavour, ...]: ...
 
     @abstractmethod
     def select[TValue, TFlavour, P](self, selector: SelectorFlavourType[T, tuple[TValue, P]] = ..., *, cast_to_tuple: bool = ..., flavour: Type[TFlavour] = ..., by: JoinType = ..., **kwargs): ...
@@ -255,21 +267,21 @@ class IStatements[T: Table](ABC):
     @overload
     def select_one[TFlavour](self, *, by: Optional[Enum] = ..., flavour: Type[TFlavour], **kwargs) -> TFlavour: ...
     @overload
-    def select_one[T1](self, selector: Callable[[T], T1 | tuple[T1]], *, by: Optional[Enum] = ...) -> T1: ...
+    def select_one[T1](self, selector: SelectorOneType[T, T1 | tuple[T1]], *, by: Optional[Enum] = ...) -> T1: ...
     @overload
-    def select_one[*TRes](self, selector: Callable[[T], tuple[*TRes]], *, by: Optional[Enum] = ...) -> tuple[*TRes]: ...
+    def select_one[*TRes](self, selector: SelectorOneType[T, tuple[*TRes]], *, by: Optional[Enum] = ...) -> tuple[*TRes]: ...
     @overload
-    def select_one[T1](self, selector: Callable[[T], tuple[T1]], *, by: Optional[Enum] = ..., flavour: Type, **kwargs) -> T1: ...
+    def select_one[T1](self, selector: SelectorOneType[T, tuple[T1]], *, by: Optional[Enum] = ..., flavour: Type, **kwargs) -> T1: ...
     @overload
-    def select_one[T1, TFlavour](self, selector: Callable[[T], T1], *, by: Optional[Enum] = ..., flavour: Type[TFlavour], **kwargs) -> TFlavour: ...
+    def select_one[T1, TFlavour](self, selector: SelectorOneType[T, T1], *, by: Optional[Enum] = ..., flavour: Type[TFlavour], **kwargs) -> TFlavour: ...
     @overload
-    def select_one[*TRest](self, selector: Callable[[T], tuple[*TRest]], *, by: Optional[Enum] = ..., flavour: Type[tuple], **kwargs) -> tuple[*TRest]: ...
+    def select_one[*TRest](self, selector: SelectorOneType[T, tuple[*TRest]], *, by: Optional[Enum] = ..., flavour: Type[tuple], **kwargs) -> tuple[*TRest]: ...
     @overload
-    def select_one[TFlavour](self, selector: Callable[[T], tuple], *, by: Optional[Enum] = ..., flavour: Type[TFlavour], **kwargs) -> TFlavour: ...
+    def select_one[TFlavour](self, selector: SelectorOneType[T, tuple], *, by: Optional[Enum] = ..., flavour: Type[TFlavour], **kwargs) -> TFlavour: ...
     @abstractmethod
     def select_one[TValue, TFlavour, *TRest](
         self,
-        selector: Optional[Callable[[T], tuple[TValue, *TRest]]] = lambda: None,
+        selector: Optional[SelectorOneType[T, tuple[TValue, *TRest]]] = lambda: None,
         *,
         flavour: Type[TFlavour] = ...,
         by: Optional[Enum] = ...,
@@ -281,23 +293,23 @@ class IStatements[T: Table](ABC):
     @overload
     def first(self) -> T: ...
     @overload
+    def first[T1](self, selector: SelectorOneType[T, T1 | tuple[T1]], *, by: Optional[Enum] = ...) -> T1: ...
+    @overload
+    def first[*TRes](self, selector: SelectorOneType[T, tuple[*TRes]], *, by: Optional[Enum] = ...) -> tuple[*TRes]: ...
+    @overload
     def first[TFlavour](self, *, by: Optional[Enum] = ..., flavour: Type[TFlavour], **kwargs) -> TFlavour: ...
     @overload
-    def first[T1](self, selector: Callable[[T], T1 | tuple[T1]], *, by: Optional[Enum] = ...) -> T1: ...
+    def first[T1](self, selector: SelectorOneType[T, tuple[T1]], *, by: Optional[Enum] = ..., flavour: Type, **kwargs) -> T1: ...
     @overload
-    def first[*TRes](self, selector: Callable[[T], tuple[*TRes]], *, by: Optional[Enum] = ...) -> tuple[*TRes]: ...
+    def first[T1, TFlavour](self, selector: SelectorOneType[T, T1], *, by: Optional[Enum] = ..., flavour: Type[TFlavour], **kwargs) -> TFlavour: ...
     @overload
-    def first[T1](self, selector: Callable[[T], tuple[T1]], *, by: Optional[Enum] = ..., flavour: Type, **kwargs) -> T1: ...
+    def first[*TRest](self, selector: SelectorOneType[T, tuple[*TRest]], *, by: Optional[Enum] = ..., flavour: Type[tuple], **kwargs) -> tuple[*TRest]: ...
     @overload
-    def first[T1, TFlavour](self, selector: Callable[[T], T1], *, by: Optional[Enum] = ..., flavour: Type[TFlavour], **kwargs) -> TFlavour: ...
-    @overload
-    def first[*TRest](self, selector: Callable[[T], tuple[*TRest]], *, by: Optional[Enum] = ..., flavour: Type[tuple], **kwargs) -> tuple[*TRest]: ...
-    @overload
-    def first[TFlavour](self, selector: Callable[[T], tuple], *, by: Optional[Enum] = ..., flavour: Type[TFlavour], **kwargs) -> TFlavour: ...
+    def first[TFlavour](self, selector: SelectorOneType[T, tuple], *, by: Optional[Enum] = ..., flavour: Type[TFlavour], **kwargs) -> TFlavour: ...
     @abstractmethod
     def first[TValue, TFlavour, *TRest](
         self,
-        selector: Optional[Callable[[T], tuple[TValue, *TRest]]] = lambda: None,
+        selector: Optional[SelectorOneType[T, tuple[TValue, *TRest]]] = lambda: None,
         *,
         flavour: Type[TFlavour] = ...,
         by: Optional[Enum] = ...,
@@ -305,9 +317,9 @@ class IStatements[T: Table](ABC):
 
     # endregion
 
-    # region group_by
+    # region groupby
     @abstractmethod
-    def group_by[TRepo](self, column: Callable[[T], TRepo]) -> IStatements[T]: ...
+    def groupby[TRepo](self, column: Callable[[T], TRepo]) -> IStatements[T]: ...
 
     # endregion
 
